--- loncom/publisher/lonpubdir.pm 2014/06/20 18:00:51 1.155
+++ loncom/publisher/lonpubdir.pm 2015/06/18 20:19:27 1.164
@@ -1,7 +1,7 @@
# The LearningOnline Network with CAPA
# Authoring Space Directory Lister
#
-# $Id: lonpubdir.pm,v 1.155 2014/06/20 18:00:51 raeburn Exp $
+# $Id: lonpubdir.pm,v 1.164 2015/06/18 20:19:27 musolffc Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -67,7 +67,9 @@ sub handler {
$r->send_http_header;
&Apache::lonhtmlcommon::clear_breadcrumbs();
- $r->print(&Apache::loncommon::start_page('Authoring Space').
+ my $js = '';
+ $r->print(&Apache::loncommon::start_page('Authoring Space', $js).
'
'.
'
'.
&mt('Your Authoring Space is currently in the location used by LON-CAPA version 2.10 and older, but your domain is using a newer LON-CAPA version ([_1]).',$version).'
'.
@@ -87,14 +89,51 @@ sub handler {
my %bombs=&Apache::lonmsg::all_url_author_res_msg($uname,$udom);
- &startpage($r, $uname, $udom, $thisdisfn); # Put out the start of page.
- &dircontrols($r,$uname,$udom,$thisdisfn); # Put out actions for directory,
- # browse/upload + new file page.
+ my $londocroot = $Apache::lonnet::perlvar{'lonDocRoot'};
+ my $current_disk_usage = &Apache::lonnet::diskusage($udom,$uname,
+ "$londocroot/priv/$udom/$uname"); # expressed in kB
+ my $disk_quota = &Apache::loncommon::get_user_quota($uname,$udom,
+ 'author'); # expressed in MB
+
+ # Put out the start of page.
+ &startpage($r, $uname, $udom, $thisdisfn, $current_disk_usage, $disk_quota);
+
+ if (!-d $fn) {
+ if (-e $fn) {
+ $r->print('
'.&mt('Requested item is a file not a directory.').'
');
+ } else {
+ $r->print('
'.&mt('The requested subdirectory does not exist.').'
');
+ $r->print(&Apache::loncommon::end_page());
+ return OK;
+ }
+
+ # Put out actions for directory, browse/upload + new file page.
+ &dircontrols($r,$uname,$udom,$thisdisfn, $current_disk_usage, $disk_quota);
&resourceactions($r,$uname,$udom,$thisdisfn); # Put out form used for printing/deletion etc.
my $numdir = 0;
my $numres = 0;
+ if ((@files == 0) && ($thisdisfn =~ m{^/$match_domain/$match_username})) {
+ if ($thisdisfn =~ m{^/$match_domain/$match_username$}) {
+ $r->print('
'.&mt('This Authoring Space is currently empty.').'
');
+ } else {
+ $r->print('
'.&mt('This subdirectory is currently empty.').'
');
+ }
+ $r->print(&Apache::loncommon::end_page());
+ return OK;
+ }
+
# Retrieving value for "sortby" and "sortorder" from QUERY_STRING
&Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},
['sortby','sortorder']);
@@ -102,58 +141,88 @@ sub handler {
# Sort by name as default, not reversed
if (! exists($env{'form.sortby'})) { $env{'form.sortby'} = 'filename' }
if (! exists($env{'form.sortorder'})) { $env{'form.sortorder'} = '' }
-
my $sortby = $env{'form.sortby'};
my $sortorder = $env{'form.sortorder'};
- opendir(DIR,$fn);
- my @files = readdir(DIR);
- closedir(DIR);
-
- if ((@files == 0) && ($thisdisfn =~ m{^/$match_domain/$match_username})) {
- $r->print('
'.&mt('This Authoring Space is currently empty.').'
'
+ # Order in which columns are displayed from left to right
+ my @order = ('filetype','actions','filename','title',
+ 'pubstatus','cmtime','size');
+
+ # Up and down arrows to indicate sort order
+ my @arrows = (' ▲',' ▼','');
+
+ # Default sort order and column title
+ my %columns = (
+ filetype => {
+ order => 'ascending',
+ text => &mt('Type'),
+ },
+ actions => {
+ # Not sortable
+ text => &mt('Actions'),
+ },
+ filename => {
+ order => 'ascending',
+ text => &mt('Name'),
+ },
+ title => {
+ order => 'ascending',
+ text => &mt('Title'),
+ },
+ pubstatus => {
+ order => 'ascending',
+ text => &mt('Status'),
+ colspan => '2',
+ },
+ cmtime => {
+ order => 'descending',
+ text => &mt('Last Modified'),
+ },
+ size => {
+ order => 'ascending',
+ text => &mt('Size').' (kB)',
+ },
+ );
+
+ # Print column headers
+ my $output = '';
+ foreach my $key (@order) {
+ my $idx;
+ # Append an up or down arrow to sorted column
+ if ($sortby eq $key) {
+ $idx = ($columns{$key}{order} eq 'ascending') ? 0:1;
+ if ($sortorder eq 'rev') { $idx ++; }
+ $idx = $idx%2;
+ } else { $idx = 2; } # No arrow if column is not sorted
+ $output .= (($columns{$key}{order}) ?
+ '
'
+ .&Apache::loncommon::start_data_table_header_row() . $output
.&Apache::loncommon::end_data_table_header_row()
);
my $dirptr=16384; # Mask indicating a directory in stat.cmode.
my $filehash = {};
foreach my $filename (@files) {
# Skip .DS_Store and hidden files
my ($extension) = ($filename=~/\.(\w+)$/);
- next if (($filename eq '.DS_Store')
- || &Apache::loncommon::fileembstyle($extension) eq 'hdn');
+ next if (($filename eq '.DS_Store')
+ || ($filename eq '.DAV')
+ || (&Apache::loncommon::fileembstyle($extension) eq 'hdn')
+ || ($filename =~ /^\._/));
my ($cmode,$csize,$cmtime)=(stat($fn.'/'.$filename))[2,7,9];
my $linkfilename = &HTML::Entities::encode('/priv'.$thisdisfn.'/'.$filename,'<>&"');
@@ -247,10 +316,23 @@ sub handler {
}
}
- $r->print( &Apache::loncommon::end_data_table()
- .&Apache::loncommon::end_page() );
-
- return OK;
+ $r->print(&Apache::loncommon::end_data_table()
+ .'
'
+ .&Apache::loncommon::start_data_table()
+ .'
'.&mt('Results in other directories:').'
'
+ .'
'
+ .'
'.&mt('Type').'
'
+ .'
'.&mt('Directory').'
'
+ .'
'.&mt('Name').'
'
+ .'
'.&mt('Title').'
'
+ .'
'.&mt('Status').'
'
+ .'
'.&mt('Last Modified').'
'
+ .'
'
+ .&Apache::loncommon::end_data_table()
+ .'
'
+ .&Apache::loncommon::end_page()
+ );
+ return OK;
}
@@ -259,14 +341,16 @@ sub handler {
# - The HTML header
# - The H1/H3 stuff which includes the directory.
#
-# startpage($r, $uame, $udom, $thisdisfn);
+# startpage($r, $uame, $udom, $thisdisfn, $current_disk_usage, $disk_quota);
# $r - The apache request object.
# $uname - User name.
# $udom - Domain name the user is logged in under.
# $thisdisfn - Displayable version of the filename.
+# $current_disk_usage - User's current disk usage (in kB).
+# $disk_quota - Disk quota for user's authoring space (in MB).
sub startpage {
- my ($r, $uname, $udom, $thisdisfn) = @_;
+ my ($r, $uname, $udom, $thisdisfn, $current_disk_usage, $disk_quota) = @_;
&Apache::loncommon::content_type($r,'text/html');
$r->send_http_header;
@@ -283,12 +367,11 @@ sub startpage {
# in start_page->bodytag->innerregister
$env{'request.noversionuri'}=$formaction;
- $r->print(&Apache::loncommon::start_page('Authoring Space'));
+ my $js = '';
+ $r->print(&Apache::loncommon::start_page('Authoring Space', $js));
- my $londocroot = $Apache::lonnet::perlvar{'lonDocRoot'};
- my $current_disk_usage = &Apache::lonnet::diskusage($udom,$uname,"$londocroot/priv/$udom/$uname");
- my $disk_quota = &Apache::loncommon::get_user_quota($uname,$udom,'author'); #expressed in MB
- $disk_quota = 1000 * $disk_quota; # convert from MB to kB
+ $disk_quota = 1024 * $disk_quota; # convert from MB to kB
$r->print(&Apache::loncommon::head_subbox(
'
'
@@ -410,7 +493,7 @@ ENDPUBDIRSCRIPT
}
sub dircontrols {
- my ($r,$uname,$udom,$thisdisfn) = @_;
+ my ($r,$uname,$udom,$thisdisfn, $current_disk_usage, $disk_quota) = @_;
my %lt=&Apache::lonlocal::texthash(
cnpd => 'Cannot publish directory',
cnrd => 'Cannot retrieve directory',
@@ -441,12 +524,18 @@ sub dircontrols {
go => 'Go',
prnt => 'Print contents of directory',
crea => 'Create a new directory or LON-CAPA document',
+ qs => 'Quick Search',
+ cs => 'Case Sensitive',
+ re => 'Regular Expression',
acti => 'Actions for current directory',
updc => 'Upload a new document',
pick => 'Please select an action to perform using the new filename',
);
my $mytype = $lt{'type'}; # avoid conflict with " and ' in javascript
- $r->print(<printf(<
@@ -102,58 +141,88 @@ sub handler {
my $filehash = {};
foreach my $filename (@files) {
- # Skip .DS_Store and hidden files
+ # Skip .DS_Store, .DAV and hidden files
my ($extension) = ($filename=~/\.(\w+)$/);